<template>
  <el-dialog
    width="90%"
    title="发料明细"
    top="5vh"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <ttable
      :table="table"
      :paramObj="paramObj"
      @handleSelectionChange="
        (val) => {
          multipleSelection = val
        }
      "
      :options="options"
      :ajaxFun="ajaxFun"
      :bottomOffset="250"
      ref="delMatUnIssueTable"
    >
      <template #toolbar></template>
    </ttable>
    <div slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >取消发料</el-button
      >
    </div>
  </el-dialog>
</template>

<script>
import {
  fetchMatIssueListPage,
  delMatUnIssue
} from '@/api/plan/manufacturingorder'
// import adaptive from '@/util/adaptive'
import ttable from '@/views/common/ztt-table.vue'
export default {
  // directives: {
  //   adaptive
  // },
  data() {
    const col = (prop, label, config) => {
      return Object.assign(
        {
          prop: prop,
          label: label,
          sort: true,
          isTrue: true,
          isSearch: true,
          searchInfoType: 'text'
        },
        config
      )
    }
    const colformat = (list) => {
      return {
        searchInfoType: 'select',
        formatter: (row, column, cellValue) => {
          if (cellValue) {
            return this[list].find((e) => e.value === cellValue).label
          }
        },
        optList: () => {
          return this[list]
        }
      }
    }
    return {
      visible: false,
      ajaxFun: fetchMatIssueListPage,
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' },
        cancelRunCreated: true
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          col('partNo', '零件号'),
          col('partName', '零件描述', {
            width: 300
          }),
          col('lotBatchNo', '批次号'),
          col('warehouse', '仓库'),
          col('locationNo', '库位号'),
          col('wdrNo', 'WDR'),
          col('qtyIssue', '下发数量'),
          col('createUser', '下发人员'),
          col('createTime', '下发时间'),
          col('unit', '单位')
        ],
        toolbar: [],
        operator: null
      },
      multipleSelection: [],
      paramObj: {},
      isSubmit: false
    }
  },
  components: {
    ttable
  },
  created() {},
  methods: {
    init(moid) {
      this.paramObj = {
        moId: moid
      }
      this.visible = true
      this.$nextTick(() => {
        this.getData()
      })
    },
    // 获取数据列表
    getData() {
      this.$refs.delMatUnIssueTable.getDataList()
    },
    saveSelectRow() {
      if (this.multipleSelection.length) {
        this.$confirm('是否确认取消发料', '警告', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal: false,
          type: 'warning'
        }).then(() => {
          this.isSubmit = true
          delMatUnIssue(this.multipleSelection.map((e) => e.id))
            .then(() => {
              this.$message.success('取消成功')
              this.visible = false
              this.$emit('refreshDataList')
            })
            .finally(() => {
              this.isSubmit = false
            })
        })
      } else {
        this.$message.error('请选择明细')
      }
    }
  }
}
</script>
<style lang="scss" scoped>
>>> .grid-header {
  display: none;
}
</style>
